==> nocc-1.8.1.tbz: www/nocc/lang/pt-br.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: pt-br.php 1931 2009-07-05 11:07:47Z gerundt $
 */

/** Brazilian Portuguese (Português do Brasil)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Crazymadlover
 * @author Eduardo.mps
 * @author GKnedo
 * @author Giovani Zamboni <zambaxtz@terra.com.br>
 * @author Renato Frederick <frederick@dahype.org>
 */

$lang_locale = 'pt_BR.UTF-8';
$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'O campo <strong>Usuário</strong> esta vazio';
$err_passwd_empty = 'O campo <strong>Senha</strong> esta vazio';
$alt_delete = 'Excluir as mensagens selecionadas';
$alt_delete_one = 'Excluir a mensagem';
$alt_new_msg = 'Nova mensagens';
$alt_reply = 'Responder ao autor';
$alt_reply_all = 'Responder à todos';
$alt_forward = 'Encaminhar';
$alt_next = 'Próximo';
$alt_prev = 'Anterior';
$title_next_page = 'Próxima. Página';
$title_prev_page = 'Página Anterior';
$title_next_msg = 'Próxima mensagem';
$title_prev_msg = 'Mensagem anterior';
$html_on = 'Ligado';
$html_theme_label = 'Tema';
$html_welcome = 'Bem vindo ao %1$s';
$html_login = 'Usuário';
$html_passwd = 'Senha';
$html_submit = 'Enviar';
$html_help = 'Ajuda';
$html_server = 'Servidor';
$html_wrong = 'O usuário ou a senha estão incorretos';
$html_retry = 'Repetir';
$html_remember = 'Lembrar Configurações';
$html_msgperpage_label = 'Mensagens por página';
$html_preferences = 'Preferências';
$html_full_name_label = 'Nome Completo';
$html_email_address_label = 'Endereço de Email';
$html_ccself = 'Cc para você mesmo';
$html_hide_addresses = 'Ocultar Endereços';
$html_outlook_quoting = 'Quotas no estilo Outlook';
$html_reply_to = 'Responder para';
$html_use_signature = 'Usar Assinatura';
$html_signature = 'Assinatura';
$html_reply_leadin_label = 'Responder com prefixo';
$html_prefs_updated = 'Preferências Atualizada';
$html_manage_folders_link = 'Gerenciar Pastas IMAP';
$html_manage_filters_link = 'Gerenciar Filtros de Email';
$html_use_graphical_smilies = 'Usar Smiles';
$html_sent_folder_label = 'Copiar emails enviados para';
$html_trash_folder_label = 'Move e-mails deletados para uma pasta específica';
$html_colored_quotes = 'Quotas Coloridas';
$html_display_struct = 'Mostrar texto estruturado';
$html_send_html_mail = 'Enviar email em formato HTML';
$html_folders = 'Pastas';
$html_folders_create_failed = 'Pasta não pôde ser criada';
$html_folders_sub_failed = 'Não foi possível asssinar a pasta!';
$html_folders_unsub_failed = 'Não foi possível cancelar assinatura deste pasta!';
$html_folders_rename_failed = 'Pasta não pode ser renomeada!';
$html_folders_updated = 'Pastas atualizadas!';
$html_folder_subscribe = 'Assinar pasta';
$html_folder_rename = 'Renomear';
$html_folder_create = 'Criar nova pasta chamda';
$html_folder_remove = 'Cancelar assinatura de';
$html_folder_delete = 'Deletar';
$html_folder_to = 'para';
$html_filter_remove = 'Deletar';
$html_filter_body = 'Corpo da Mensagem';
$html_filter_subject = 'Assunto da Mensagem';
$html_filter_to = 'Campo para';
$html_filter_cc = 'Campo Cc';
$html_filter_from = 'Campo De';
$html_filter_change_tip = 'Para modificar um filtro simplesmente sobrescreva-o.';
$html_reapply_filters = 'Reaplicar todos os filtros';
$html_filter_contains = 'contém';
$html_filter_name = 'Nome do filtro';
$html_filter_action = 'Ação do Filtro';
$html_filter_moveto = 'Mover para';
$html_select_one = '--Selecione Uma--';
$html_and = 'E';
$html_new_msg_in = 'Novas mensagens em';
$html_or = 'Ou';
$html_move = 'Mover';
$html_copy = 'Copiar';
$html_messages_to = 'mensagens selecionadas para';
$html_gotopage = 'Ir para página';
$html_gotofolder = 'Ir para Pasta';
$html_other_folders = 'Lista de Pastas';
$html_page = 'Página';
$html_of = 'de';
$html_view_header = 'Ver cabeçalho';
$html_remove_header = 'Esconder cabeçalho';
$html_inbox = 'Caixa de Entrada';
$html_new_msg = 'Nova Mensagem';
$html_reply = 'Responder';
$html_reply_short = 'Res';
$html_reply_all = 'Responder à todos';
$html_forward = 'Encaminhar';
$html_forward_short = 'Enc';
$html_forward_info = 'A mensagem encaminhada será enviada como anexo desta mensagem.';
$html_delete = 'Excluir';
$html_new = 'Novo';
$html_mark = 'Excluir';
$html_att_label = 'Anexo';
$html_atts_label = 'Anexos';
$html_att_unknown = '[Desconhecido]';
$html_attach = 'Anexar arquivo';
$html_attach_forget = 'Você precisa anexar seus arquivos antes de enviar esta mensagem !';
$html_attach_delete = 'Remover anexos selecionados';
$html_attach_none = 'Você precisa selecionar um arquivo para anexar!';
$html_sort_by = 'Ordenar por';
$html_sort = 'Ordenar';
$html_from = 'De';
$html_subject = 'Assunto';
$html_date = 'Data';
$html_sent = 'Enviar';
$html_wrote = 'escreveu';
$html_size = 'Tamanho';
$html_totalsize = 'Tamanho Total';
$html_kb = 'kb';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bytes';
$html_filename = 'Nome do Arquivo';
$html_to = 'Para';
$html_cc = 'Cc';
$html_bcc_label = 'Cco';
$html_nosubject = 'Sem assunto';
$html_send = 'Enviar';
$html_cancel = 'Cancelar';
$html_no_mail = 'Sem mensagens.';
$html_logout = 'Sair';
$html_msg = 'Mensagem';
$html_msgs = 'Mensagens';
$html_configuration = 'Este servidor ainda não esta bem configurado !';
$html_priority_label = 'Prioridade';
$html_lowest = 'Mais Baixo';
$html_low = 'Baixa';
$html_normal = 'Normal';
$html_high = 'Alta';
$html_highest = 'Mais Alto';
$html_receipt = 'Pedir confirmação de Leitura';
$html_select = 'Selecionar';
$html_select_all = 'Inverter Seleção';
$html_loading_image = 'Carregando imagem';
$html_send_confirmed = 'Sua mensagem foi aceita para entrega';
$html_no_sendaction = 'Sem ação especificada. Tente habilitar JavaScript.';
$html_error_occurred = 'Ocorreu um erro';
$html_prefs_file_error = 'Impossível abrir arquivo de preferências para gravação.';
$html_wrap = 'Quebrar mensagens de saída em :';
$html_wrap_none = 'Nenhuma';
$html_usenet_separator = 'Separador Usenet ("-- \n") Antes da assinatura';
$html_mark_as = 'Marcar como';
$html_read = 'lido';
$html_unread = 'não lido';
$html_encoding_label = 'Codificação de Caracteres';
$html_add = 'Adicionar';
$html_contacts = '%1$s Contatos';
$html_modify = 'Modificar';
$html_back = 'Voltar';
$html_contact_add = 'Adicionar novo contato';
$html_contact_mod = 'Modificar um contato';
$html_contact_first = 'Primeiro Nome';
$html_contact_last = 'Último Nome';
$html_contact_nick = 'Apelido';
$html_contact_mail = 'E-Mail';
$html_contact_list = 'Listas de contatos de %1$s';
$html_contact_del = 'da lista de contatos';
$html_contact_count = '%1$d Contatos';
$html_contact_err1 = 'Máximo número de contatos é';
$html_contact_err2 = 'Você não pode adicionar um novo contato';
$html_contact_err3 = 'Você não tem acesso à lista de contatos';
$html_contact_none = 'Nenhum contato foi encontrado.';
$html_del_msg = 'Deletar mensagens selecionadas ?';
$html_down_mail = 'Baixar';
$original_msg = '-- Mensagem Original --';
$to_empty = 'Campo \'Para\' não pode estar vazio !';
$html_images_warning = 'Para sua segurança, imagens remotas não são mostradas.';
$html_images_display = 'Mostrar imagens';
$html_smtp_error_no_conn = 'Impossível abrir conexão SMTP';
$html_smtp_error_unexpected = 'Resposta SMTP inesperada:';
$lang_could_not_connect = 'Não foi possível conectar ao servidor';
$lang_invalid_msg_num = 'Número inválido de mensagem';
$html_file_upload_attack = 'Possível ataque de upload do arquivo';
$html_invalid_email_address = 'Endereço de e-mail inválido';
$html_invalid_msg_per_page = 'Número de mensagens por página inválida';
$html_invalid_wrap_msg = 'Larguda de quebra de mensagem inválida';
$html_seperate_msg_win = 'Mensagens em uma janela separada';
$html_err_file_contacts = 'Impossível abrir arquivo de contatos para gravação.';
$html_session_file_error = 'Impossível abrir arquivo de dessão para gravação.';
$html_login_not_allowed = 'Este login não é permitido para conexão.';
$lang_err_send_delay = 'Você tem de aguardar um pouco entre suas ações (%1$d segundos)';
$html_search = 'Buscar';

==> nocc-1.8.3.tbz: www/nocc/lang/pt-br.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: pt-br.php 2181 2010-04-27 09:07:03Z gerundt $
 */

/** Brazilian Portuguese (Português do Brasil)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Crazymadlover
 * @author Eduardo.mps
 * @author GKnedo
 * @author Giovani Zamboni <zambaxtz@terra.com.br>
 * @author Luckas Blade
 * @author Renato Frederick <frederick@dahype.org>
 * @author Rodrigo Avila
 */

$lang_locale = 'pt_BR.UTF-8';
$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'O campo <strong>Usuário</strong> esta vazio';
$err_passwd_empty = 'O campo <strong>Senha</strong> esta vazio';
$alt_delete = 'Excluir as mensagens selecionadas';
$alt_delete_one = 'Excluir a mensagem';
$alt_new_msg = 'Nova mensagens';
$alt_reply = 'Responder ao autor';
$alt_reply_all = 'Responder à todos';
$alt_forward = 'Encaminhar';
$alt_next = 'Próximo';
$alt_prev = 'Anterior';
$title_next_page = 'Próxima. Página';
$title_prev_page = 'Página Anterior';
$title_next_msg = 'Próxima mensagem';
$title_prev_msg = 'Mensagem anterior';
$html_theme_label = 'Tema:';
$html_welcome = 'Bem vindo ao %1$s';
$html_login = 'Usuário';
$html_user_label = 'Usuário:';
$html_passwd_label = 'Senha:';
$html_submit = 'Enviar';
$html_help = 'Ajuda';
$html_server_label = 'Servidor:';
$html_wrong = 'O usuário ou a senha estão incorretos';
$html_retry = 'Repetir';
$html_remember = 'Lembrar Configurações';
$html_lang_label = 'Língua:';
$html_msgperpage_label = 'Mensagens por página:';
$html_preferences = 'Preferências';
$html_full_name_label = 'Nome Completo:';
$html_email_address_label = 'Endereço de Email:';
$html_ccself = 'Cc para você mesmo';
$html_hide_addresses = 'Ocultar Endereços';
$html_outlook_quoting = 'Quotas no estilo Outlook';
$html_reply_to = 'Responder para';
$html_use_signature = 'Usar Assinatura';
$html_signature = 'Assinatura';
$html_signature_label = 'Assinatura:';
$html_reply_leadin_label = 'Responder com prefixo:';
$html_prefs_updated = 'Preferências Atualizada';
$html_manage_folders_link = 'Gerenciar Pastas IMAP';
$html_manage_filters_link = 'Gerenciar Filtros de Email';
$html_use_graphical_smilies = 'Usar Smiles';
$html_sent_folder_label = 'Copiar emails enviados para a pasta específica:';
$html_trash_folder_label = 'Move e-mails deletados para uma pasta específica:';
$html_colored_quotes = 'Quotas Coloridas';
$html_display_struct = 'Mostrar texto estruturado';
$html_send_html_mail = 'Enviar email em formato HTML';
$html_folders = 'Pastas';
$html_folders_create_failed = 'Pasta não pôde ser criada';
$html_folders_sub_failed = 'Não foi possível asssinar a pasta!';
$html_folders_unsub_failed = 'Não foi possível cancelar assinatura deste pasta!';
$html_folders_rename_failed = 'Pasta não pode ser renomeada!';
$html_folders_updated = 'Pastas atualizadas!';
$html_folder_subscribe = 'Assinar pasta';
$html_folder_rename = 'Renomear';
$html_folder_create = 'Criar nova pasta chamda';
$html_folder_remove = 'Cancelar assinatura de';
$html_folder_delete = 'Deletar';
$html_folder_to = 'para';
$html_filter_remove = 'Deletar';
$html_filter_body = 'Corpo da Mensagem';
$html_filter_subject = 'Assunto da Mensagem';
$html_filter_to = 'Campo para';
$html_filter_cc = 'Campo Cc';
$html_filter_from = 'Campo De';
$html_filter_change_tip = 'Para modificar um filtro simplesmente sobrescreva-o.';
$html_reapply_filters = 'Reaplicar todos os filtros';
$html_filter_contains = 'contém';
$html_filter_name = 'Nome do filtro';
$html_filter_action = 'Ação do Filtro';
$html_filter_moveto = 'Mover para';
$html_select_one = '--Selecione Uma--';
$html_and = 'E';
$html_new_msg_in = 'Novas mensagens em';
$html_or = 'Ou';
$html_move = 'Mover';
$html_copy = 'Copiar';
$html_messages_to = 'mensagens selecionadas para';
$html_gotopage = 'Ir para página';
$html_gotofolder = 'Ir para Pasta';
$html_other_folders = 'Lista de Pastas';
$html_page = 'Página';
$html_of = 'de';
$html_view_header = 'Ver cabeçalho';
$html_remove_header = 'Esconder cabeçalho';
$html_inbox = 'Caixa de Entrada';
$html_new_msg = 'Nova Mensagem';
$html_reply = 'Responder';
$html_reply_short = 'Res:';
$html_reply_all = 'Responder à todos';
$html_forward = 'Encaminhar';
$html_forward_short = 'Enc:';
$html_forward_info = 'A mensagem encaminhada será enviada como anexo desta mensagem.';
$html_delete = 'Excluir';
$html_new = 'Novo';
$html_mark = 'Excluir';
$html_att_label = 'Anexo:';
$html_atts_label = 'Anexos:';
$html_unknown = '[Desconhecido]';
$html_attach = 'Anexar arquivo';
$html_attach_forget = 'Você precisa anexar seus arquivos antes de enviar esta mensagem !';
$html_attach_delete = 'Remover anexos selecionados';
$html_attach_none = 'Você precisa selecionar um arquivo para anexar!';
$html_sort_by = 'Ordenar por';
$html_sort = 'Ordenar';
$html_from = 'De';
$html_from_label = 'De:';
$html_subject = 'Assunto';
$html_subject_label = 'Assunto:';
$html_date = 'Data';
$html_date_label = 'Data:';
$html_sent_label = 'Enviado:';
$html_wrote = 'escreveu';
$html_size = 'Tamanho';
$html_totalsize = 'Tamanho Total';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bytes';
$html_filename = 'Nome do Arquivo';
$html_to = 'Para';
$html_to_label = 'Para:';
$html_cc = 'Cc';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Cco:';
$html_nosubject = 'Sem assunto';
$html_send = 'Enviar';
$html_cancel = 'Cancelar';
$html_no_mail = 'Sem mensagens.';
$html_logout = 'Sair';
$html_msg = 'Mensagem';
$html_msgs = 'Mensagens';
$html_configuration = 'Este servidor ainda não esta bem configurado !';
$html_priority = 'Prioridade';
$html_priority_label = 'Prioridade:';
$html_lowest = 'Mais Baixo';
$html_low = 'Baixa';
$html_normal = 'Normal';
$html_high = 'Alta';
$html_highest = 'Mais Alto';
$html_flagged = 'Marcado';
$html_spam = 'Spam';
$html_spam_warning = 'Esta mensagem foi classificada como spam.';
$html_receipt = 'Pedir confirmação de Leitura';
$html_select = 'Selecionar';
$html_select_all = 'Inverter Seleção';
$html_select_contacts = 'Selecionar contatos';
$html_loading_image = 'Carregando imagem';
$html_send_confirmed = 'Sua mensagem foi aceita para entrega';
$html_no_sendaction = 'Sem ação especificada. Tente habilitar JavaScript.';
$html_error_occurred = 'Ocorreu um erro';
$html_prefs_file_error = 'Impossível abrir arquivo de preferências para gravação.';
$html_wrap = 'Número de caracteres para quebra de linha em mensagens de saída:';
$html_wrap_none = 'Sem quebra de linha';
$html_usenet_separator = 'Separador Usenet ("-- \n") Antes da assinatura';
$html_mark_as = 'Marcar como';
$html_read = 'lido';
$html_unread = 'não lido';
$html_encoding_label = 'Codificação de Caracteres:';
$html_add = 'Adicionar';
$html_contacts = '%1$s Contatos';
$html_modify = 'Modificar';
$html_back = 'Voltar';
$html_contact_add = 'Adicionar novo contato';
$html_contact_mod = 'Modificar um contato';
$html_contact_first = 'Primeiro Nome';
$html_contact_last = 'Último Nome';
$html_contact_nick = 'Apelido';
$html_contact_mail = 'E-Mail';
$html_contact_list = 'Listas de contatos de %1$s';
$html_contact_del = 'da lista de contatos';
$html_contact_count = '%1$d Contatos';
$html_contact_err1 = 'Máximo número de contatos é "%1$d"';
$html_contact_err2 = 'Você não pode adicionar um novo contato';
$html_contact_err3 = 'Você não tem acesso à lista de contatos';
$html_contact_none = 'Nenhum contato foi encontrado.';
$html_del_msg = 'Deletar mensagens selecionadas ?';
$html_down_mail = 'Baixar';
$original_msg = '-- Mensagem Original --';
$to_empty = 'Campo \'Para\' não pode estar vazio !';
$html_images_warning = 'Para sua segurança, imagens remotas não são mostradas.';
$html_images_display = 'Mostrar imagens';
$html_smtp_error_no_conn = 'Impossível abrir conexão SMTP';
$html_smtp_error_unexpected = 'Resposta SMTP inesperada:';
$lang_could_not_connect = 'Não foi possível conectar ao servidor';
$lang_invalid_msg_num = 'Número inválido de mensagem';
$html_file_upload_attack = 'Possível ataque de upload do arquivo';
$html_invalid_email_address = 'Endereço de e-mail inválido';
$html_invalid_msg_per_page = 'Número de mensagens por página inválida';
$html_invalid_wrap_msg = 'Larguda de quebra de mensagem inválida';
$html_seperate_msg_win = 'Mensagens em uma janela separada';
$html_err_file_contacts = 'Impossível abrir arquivo de contatos para gravação.';
$html_session_file_error = 'Impossível abrir arquivo de dessão para gravação.';
$html_login_not_allowed = 'Este login não é permitido para conexão.';
$lang_err_send_delay = 'Você deve aguardar entre dois e-mails (%1$d segundos)';
$html_search = 'Buscar';
